pub fn simple_scan<V: Vmer, P: Kmer>(
k: usize,
seq: &V,
permutation: &[usize],
rc: bool,
) -> Vec<MspInterval>👎Deprecated:
Please use the Scanner type instead
Determine MSP substrings of seq, for given k and p. Returns a vector of tuples indicating the substrings, and the pmer values: (p-mer value, min p-mer position, start position, end position) permutation is a permutation of the lexicographically-sorted set of all pmers. A permutation of pmers sorted by their inverse frequency in the dataset will give the most even bucketing of MSPs over pmers.